@@ -1,9 +1,9 @@
 #
-# $Id: String.pm,v 0.2 2004/01/06 03:33:26 sts Exp $
+# $Id: String.pm,v 0.21 2004/01/06 17:27:52 sts Exp $
 
 package Convert::ASCII::String;
 
-our $VERSION = '0.2';
+our $VERSION = '0.21';
 
 use strict 'vars';
 use warnings;
@@ -29,21 +29,21 @@ Convert::ASCII::String - convert character strings to ASCII and vice versa.
 
 =head1 SYNOPSIS
 
-    use Convert::ASCII::String q/:all/;
+ use Convert::ASCII::String q/:all/;
 
-    our $wisdom = 'Premature optimization is the root of all evil.';
+ our $wisdom = 'Premature optimization is the root of all evil.';
 
-    string2ascii (\$wisdom, '.');
+ string2ascii (\$wisdom, '.');
 
-      80.114.101.109.97.116.117.114.101.32.
-      111.112.116.105.109.105.122.97.116.105.
-      111.110.32.105.115.32.116.104.101.32.114.
-      111.111.116.32.111.102.32.97.108.108.32.
-      101.118.105.108.46
+   80.114.101.109.97.116.117.114.101.32.
+   111.112.116.105.109.105.122.97.116.105.
+   111.110.32.105.115.32.116.104.101.32.114.
+   111.111.116.32.111.102.32.97.108.108.32.
+   101.118.105.108.46
 
-    ascii2string (\$wisdom, '.');
+ ascii2string (\$wisdom, '.');
 
-      Premature optimization is the root of all evil.
+   Premature optimization is the root of all evil.
 
 =head1 DESCRIPTION
 
@@ -77,15 +77,15 @@ the array. Thus string transformation with an item separator.
 
 =head2 string2ascii
 
-Convert a character string to ASCII inserting a separator between each ASCII code.
+Converts a character string to ASCII inserting a separator between each ASCII code.
 
 The separator is optional.
 
-    string2ascii (\$data, '.');
+ string2ascii (\$data, '.');
 
-    or
+ or
 
-    string2ascii (\$data);
+ string2ascii (\$data);
 
 Beware, second option will not allow back converting from ASCII.
 
@@ -120,7 +120,7 @@ sub string2ascii {
 
 And vice versa.
 
-    ascii2string (\$data, '.');
+ ascii2string (\$data, '.');
 
 B<RETURN CODES>
 
@@ -170,7 +170,7 @@ Function delivery becomes then superfluous.
 
 C<string2ascii(), ascii2string()> upon request.
 
-=head2 TAGS
+B<TAGS>
 
 C<:all - *()>
 
